summaryrefslogtreecommitdiffstats
path: root/cpukit/sapi/include/rtems/sptables.h
diff options
context:
space:
mode:
authorJoel Sherrill <joel.sherrill@OARcorp.com>2008-02-26 19:21:44 +0000
committerJoel Sherrill <joel.sherrill@OARcorp.com>2008-02-26 19:21:44 +0000
commitc2564b6c4a3feb76ba8400bf38894c73bf840c2a (patch)
tree9f1b72e06768e7a45184c0fd515c35a49a3e6e8d /cpukit/sapi/include/rtems/sptables.h
parent2008-02-26 Joel Sherrill <joel.sherrill@OARcorp.com> (diff)
downloadrtems-c2564b6c4a3feb76ba8400bf38894c73bf840c2a.tar.bz2
2008-02-26 Joel Sherrill <joel.sherrill@OARcorp.com>
* sapi/include/rtems/config.h, sapi/include/rtems/sptables.h: Add missing field to default multiprocessing configuration table. Also document fields in Doxygen format.
Diffstat (limited to '')
-rw-r--r--cpukit/sapi/include/rtems/sptables.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/cpukit/sapi/include/rtems/sptables.h b/cpukit/sapi/include/rtems/sptables.h
index 226c9a30fb..64b93f5c98 100644
--- a/cpukit/sapi/include/rtems/sptables.h
+++ b/cpukit/sapi/include/rtems/sptables.h
@@ -55,11 +55,12 @@ extern "C" {
#if defined(SAPI_INIT)
const rtems_multiprocessing_table
_Initialization_Default_multiprocessing_table = {
- 1, /* local node number */
- 1, /* maximum number nodes in system */
- 0, /* maximum number global objects */
- 0, /* maximum number proxies */
- NULL, /* pointer to MPCI address table */
+ 1, /* local node number */
+ 1, /* maximum number nodes in system */
+ 0, /* maximum number global objects */
+ 0, /* maximum number proxies */
+ RTEMS_MINIMUM_STACK_SIZE, /* MPCI receive server stack size */
+ NULL, /* pointer to MPCI address table */
};
#else
extern const rtems_multiprocessing_table